@@ -94,13 +94,23 @@ impl Client {
     ///
     /// (Note: no trailing slash on either endpoint style.)
     pub fn new(base_url: &str, user_agent: &str) -> Result<Self> {
+        let concurrency = if base_url.contains("rest.php") {
+            // rest.php, treat it like api.php and only allow 1 request
+            // at a time
+            1
+        } else {
+            // Most likely Restbase, which allows for 200 requests/second. We
+            // don't exactly measure requests per second, so lowball it to 100
+            // concurrent requests, and assume that all of our requests will
+            // take longer than 0.5 seconds.
+            100
+        };
         Ok(Client {
             http: HttpClient::builder()
                 .user_agent(format!("parsoid-rs/{} {}", VERSION, user_agent))
                 .build()?,
             base_url: base_url.to_string(),
-            // TODO: can we do better than just hardcoding a concurrency of 10?
-            semaphore: Arc::new(Semaphore::new(10)),
+            semaphore: Arc::new(Semaphore::new(concurrency)),
         })
     }
 
@@ -145,6 +155,7 @@ impl Client {
         } else {
             url_part
         };
+        let url = format!("{}?redirect=false", url);
         let req = self
             .http
             .get(&url)
