@@ -633,3 +633,27 @@ async fn test_spec_version() -> Result<()> {
     assert_eq!(&code.spec_version().unwrap(), "2.3.0");
     Ok(())
 }
+
+/// Regression test for extension-generated <section> tags
+/// https://gitlab.com/mwbot-rs/parsoid/-/issues/14
+#[tokio::test]
+async fn test_extension_sections() -> Result<()> {
+    let client = build_client();
+    let code = client.get("Help:TemplateData").await?;
+    for section in code.iter_sections() {
+        // Verify none of these panic
+        section.section_id();
+        section.is_pseudo_section();
+        section.heading();
+    }
+    for section in code
+        .inclusive_descendants()
+        .filter_map(|node| node.as_section())
+    {
+        // Verify none of these panic
+        section.section_id();
+        section.is_pseudo_section();
+        section.heading();
+    }
+    Ok(())
+}
